@@ -37,7 +37,8 @@ var group__spa__loop =
       [ "add_hook", "structspa__loop__control__methods.html#a4af155a89512ec591bac117a3907e8c4", null ],
       [ "enter", "structspa__loop__control__methods.html#a4a64700ab318b03abb1a5ec5a5309f8a", null ],
       [ "leave", "structspa__loop__control__methods.html#a84177384a1a726c4b35a3e1d9bc8f30f", null ],
-      [ "iterate", "structspa__loop__control__methods.html#a2d30cbd197ae33a77b5ccce2216ca61a", null ]
+      [ "iterate", "structspa__loop__control__methods.html#a2d30cbd197ae33a77b5ccce2216ca61a", null ],
+      [ "check", "structspa__loop__control__methods.html#a6fd7cce6e454d8bbaff7f13d2035f6c9", null ]
     ] ],
     [ "spa_loop_utils_methods", "structspa__loop__utils__methods.html", [
       [ "version", "structspa__loop__utils__methods.html#aefb69d2a6ad30b352b4414401a55f3e7", null ],
@@ -52,6 +53,13 @@ var group__spa__loop =
       [ "add_signal", "structspa__loop__utils__methods.html#af9604ab5944fce7539516ff227ddc2f9", null ],
       [ "destroy_source", "structspa__loop__utils__methods.html#acb650a30486b87fcab5859afd000d913", null ]
     ] ],
+    [ "spa_source_func_t", "group__spa__loop.html#ga809d037b8643139b58878b4b31b28cf6", null ],
+    [ "spa_invoke_func_t", "group__spa__loop.html#gab59a4a2bc60d5c26983a0e0edabc6617", null ],
+    [ "spa_source_io_func_t", "group__spa__loop.html#gacb78ee7f8a1948db3767b3f9c82f7370", null ],
+    [ "spa_source_idle_func_t", "group__spa__loop.html#ga710acda9d2c12a7d44236e5b1024e941", null ],
+    [ "spa_source_event_func_t", "group__spa__loop.html#ga4de35545ca7478aeaf64f46434262346", null ],
+    [ "spa_source_timer_func_t", "group__spa__loop.html#ga12c55826c9d89a9d385da0363ee586d9", null ],
+    [ "spa_source_signal_func_t", "group__spa__loop.html#ga5484a18b8cc8060d6397589465948378", null ],
     [ "SPA_TYPE_INTERFACE_Loop", "group__spa__loop.html#ga5ea06c2ace410d56b97b466704b3ded7", null ],
     [ "SPA_TYPE_INTERFACE_DataLoop", "group__spa__loop.html#ga5be1a481702843ffab8cfe42d3b6cfe1", null ],
     [ "SPA_VERSION_LOOP", "group__spa__loop.html#ga50c88c59a795523063c7f48e517fce74", null ],
@@ -71,11 +79,14 @@ var group__spa__loop =
     [ "SPA_VERSION_LOOP_CONTROL_METHODS", "group__spa__loop.html#ga2b1b3decfe2f7f50d690dba084a6f83e", null ],
     [ "spa_loop_control_method_v", "group__spa__loop.html#ga0f531ff1357bf1f6ad225faa1f99b265", null ],
     [ "spa_loop_control_method_r", "group__spa__loop.html#ga4b23dfd9d8eadc0364b62ff9bdc25e82", null ],
+    [ "spa_loop_control_method_fast_r", "group__spa__loop.html#ga4ee9dd3d66c0bf6f35837e150c59ccc2", null ],
     [ "spa_loop_control_get_fd", "group__spa__loop.html#gab1b169d1e380c8af23a07c8b149139df", null ],
     [ "spa_loop_control_add_hook", "group__spa__loop.html#gaffe08d7788d04fa44c44fda7ab3649bb", null ],
     [ "spa_loop_control_enter", "group__spa__loop.html#ga32dfd8283bd79d057fefb94a7e1f653c", null ],
     [ "spa_loop_control_leave", "group__spa__loop.html#ga3ab19534c467fdf6055e1db9a2144e9b", null ],
     [ "spa_loop_control_iterate", "group__spa__loop.html#ga3bae0b32100f5752b3372a505c8e04f6", null ],
+    [ "spa_loop_control_check", "group__spa__loop.html#gafdc6876cd766fafc297841accedcd105", null ],
+    [ "spa_loop_control_iterate_fast", "group__spa__loop.html#gaa4db60dd6841e3c590446307fb16ea36", null ],
     [ "SPA_VERSION_LOOP_UTILS_METHODS", "group__spa__loop.html#ga3b9f5ee85f8290ef943a23ceaf5181eb", null ],
     [ "spa_loop_utils_method_v", "group__spa__loop.html#ga48a9f2265639949de21d784ca415ecc7", null ],
     [ "spa_loop_utils_method_r", "group__spa__loop.html#gad5742d5525667f7c2287e73ec46df0e1", null ],
@@ -89,12 +100,5 @@ var group__spa__loop =
     [ "spa_loop_utils_add_timer", "group__spa__loop.html#ga7011bd80bca03b69aabd7a0e248c8454", null ],
     [ "spa_loop_utils_update_timer", "group__spa__loop.html#ga3192e99cc1772361096a4c5d3f0fd6da", null ],
     [ "spa_loop_utils_add_signal", "group__spa__loop.html#gae18de1c27e64c87d1babd2e1ce384d11", null ],
-    [ "spa_loop_utils_destroy_source", "group__spa__loop.html#gad316355ee8463e9c6bf0f515801b1a91", null ],
-    [ "spa_source_func_t", "group__spa__loop.html#ga809d037b8643139b58878b4b31b28cf6", null ],
-    [ "spa_invoke_func_t", "group__spa__loop.html#gab59a4a2bc60d5c26983a0e0edabc6617", null ],
-    [ "spa_source_io_func_t", "group__spa__loop.html#gacb78ee7f8a1948db3767b3f9c82f7370", null ],
-    [ "spa_source_idle_func_t", "group__spa__loop.html#ga710acda9d2c12a7d44236e5b1024e941", null ],
-    [ "spa_source_event_func_t", "group__spa__loop.html#ga4de35545ca7478aeaf64f46434262346", null ],
-    [ "spa_source_timer_func_t", "group__spa__loop.html#ga12c55826c9d89a9d385da0363ee586d9", null ],
-    [ "spa_source_signal_func_t", "group__spa__loop.html#ga5484a18b8cc8060d6397589465948378", null ]
+    [ "spa_loop_utils_destroy_source", "group__spa__loop.html#gad316355ee8463e9c6bf0f515801b1a91", null ]
 ];
\ No newline at end of file
