@@ -1,5 +1,6 @@
 var NAVTREEINDEX17 =
 {
+"structpw__client__info.html":[8,3,3,1],
 "structpw__client__info.html#a8585e5629d10bb4359ede29782fd7c21":[8,3,3,1,0],
 "structpw__client__info.html#a9123521af948ea7b720d1ebb0f39c66b":[8,3,3,1,1],
 "structpw__client__methods.html":[8,3,3,3],
@@ -248,6 +249,5 @@ var NAVTREEINDEX17 =
 "structpw__impl__factory__implementation.html#a99eef2345bd7b402f47ad72beb6ebfe7":[8,4,3,2,1],
 "structpw__impl__factory__implementation.html#ab63e939995687efd690f736730021e7f":[8,4,3,2,0],
 "structpw__impl__link.html":[8,4,4,2],
-"structpw__impl__link.html":[8,4,8,3],
-"structpw__impl__link__events.html":[8,4,4,1]
+"structpw__impl__link.html":[8,4,8,3]
 };
